==> ice-3.7.5.tgz: package/src/es5/IceStorm/Metrics.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.5
//
// <auto-generated>
//
// Generated from file `Metrics.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */
(function (module, require, exports) {
  var Ice = require("ice/src/es5").Ice;

  var _ModuleRegistry = Ice._ModuleRegistry;

  var IceMX = require("ice/src/es5").IceMX;

  var Slice = Ice.Slice;
  var iceC_IceMX_TopicMetrics_ids = ["::Ice::Object", "::IceMX::Metrics", "::IceMX::TopicMetrics"];
  /**
   * Provides information on IceStorm topics.
   *
   **/

  IceMX.TopicMetrics = /*#__PURE__*/function (_IceMX$Metrics) {
    _inherits(_class, _IceMX$Metrics);

    var _super = _createSuper(_class);

    function _class(id, total, current, totalLifetime, failures) {
      var _this;

      var published = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : new Ice.Long(0, 0);
      var forwarded = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : new Ice.Long(0, 0);

      _classCallCheck(this, _class);

      _this = _super.call(this, id, total, current, totalLifetime, failures);
      _this.published = published;
      _this.forwarded = forwarded;
      return _this;
    }

    _createClass(_class, [{
      key: "_iceWriteMemberImpl",
      value: function _iceWriteMemberImpl(ostr) {
        ostr.writeLong(this.published);
        ostr.writeLong(this.forwarded);
      }
    }, {
      key: "_iceReadMemberImpl",
      value: function _iceReadMemberImpl(istr) {
        this.published = istr.readLong();
        this.forwarded = istr.readLong();
      }
    }]);

    return _class;
  }(IceMX.Metrics);

  Slice.defineValue(IceMX.TopicMetrics, iceC_IceMX_TopicMetrics_ids[2], false);
  var iceC_IceMX_SubscriberMetrics_ids = ["::Ice::Object", "::IceMX::Metrics", "::IceMX::SubscriberMetrics"];
  /**
   * Provides information on IceStorm subscribers.
   *
   **/

  IceMX.SubscriberMetrics = /*#__PURE__*/function (_IceMX$Metrics2) {
    _inherits(_class2, _IceMX$Metrics2);

    var _super2 = _createSuper(_class2);

    function _class2(id, total, current, totalLifetime, failures) {
      var _this2;

      var queued = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 0;
      var outstanding = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 0;
      var delivered = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : new Ice.Long(0, 0);

      _classCallCheck(this, _class2);

      _this2 = _super2.call(this, id, total, current, totalLifetime, failures);
      _this2.queued = queued;
      _this2.outstanding = outstanding;
      _this2.delivered = delivered;
      return _this2;
    }

    _createClass(_class2, [{
      key: "_iceWriteMemberImpl",
      value: function _iceWriteMemberImpl(ostr) {
        ostr.writeInt(this.queued);
        ostr.writeInt(this.outstanding);
        ostr.writeLong(this.delivered);
      }
    }, {
      key: "_iceReadMemberImpl",
      value: function _iceReadMemberImpl(istr) {
        this.queued = istr.readInt();
        this.outstanding = istr.readInt();
        this.delivered = istr.readLong();
      }
    }]);

    return _class2;
  }(IceMX.Metrics);

  Slice.defineValue(IceMX.SubscriberMetrics, iceC_IceMX_SubscriberMetrics_ids[2], false);
  exports.IceMX = IceMX;
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);

==> ice-3.7.70.tgz: package/src/es5/IceStorm/Metrics.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.7
//
// <auto-generated>
//
// Generated from file `Metrics.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */
(function (module, require, exports) {
  var Ice = require("ice/src/es5").Ice;

  var _ModuleRegistry = Ice._ModuleRegistry;

  var IceMX = require("ice/src/es5").IceMX;

  var Slice = Ice.Slice;
  var iceC_IceMX_TopicMetrics_ids = ["::Ice::Object", "::IceMX::Metrics", "::IceMX::TopicMetrics"];
  /**
   * Provides information on IceStorm topics.
   *
   **/

  IceMX.TopicMetrics = /*#__PURE__*/function (_IceMX$Metrics) {
    _inherits(_class, _IceMX$Metrics);

    var _super = _createSuper(_class);

    function _class(id, total, current, totalLifetime, failures) {
      var _this;

      var published = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : new Ice.Long(0, 0);
      var forwarded = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : new Ice.Long(0, 0);

      _classCallCheck(this, _class);

      _this = _super.call(this, id, total, current, totalLifetime, failures);
      _this.published = published;
      _this.forwarded = forwarded;
      return _this;
    }

    _createClass(_class, [{
      key: "_iceWriteMemberImpl",
      value: function _iceWriteMemberImpl(ostr) {
        ostr.writeLong(this.published);
        ostr.writeLong(this.forwarded);
      }
    }, {
      key: "_iceReadMemberImpl",
      value: function _iceReadMemberImpl(istr) {
        this.published = istr.readLong();
        this.forwarded = istr.readLong();
      }
    }]);

    return _class;
  }(IceMX.Metrics);

  Slice.defineValue(IceMX.TopicMetrics, iceC_IceMX_TopicMetrics_ids[2], false);
  var iceC_IceMX_SubscriberMetrics_ids = ["::Ice::Object", "::IceMX::Metrics", "::IceMX::SubscriberMetrics"];
  /**
   * Provides information on IceStorm subscribers.
   *
   **/

  IceMX.SubscriberMetrics = /*#__PURE__*/function (_IceMX$Metrics2) {
    _inherits(_class2, _IceMX$Metrics2);

    var _super2 = _createSuper(_class2);

    function _class2(id, total, current, totalLifetime, failures) {
      var _this2;

      var queued = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 0;
      var outstanding = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 0;
      var delivered = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : new Ice.Long(0, 0);

      _classCallCheck(this, _class2);

      _this2 = _super2.call(this, id, total, current, totalLifetime, failures);
      _this2.queued = queued;
      _this2.outstanding = outstanding;
      _this2.delivered = delivered;
      return _this2;
    }

    _createClass(_class2, [{
      key: "_iceWriteMemberImpl",
      value: function _iceWriteMemberImpl(ostr) {
        ostr.writeInt(this.queued);
        ostr.writeInt(this.outstanding);
        ostr.writeLong(this.delivered);
      }
    }, {
      key: "_iceReadMemberImpl",
      value: function _iceReadMemberImpl(istr) {
        this.queued = istr.readInt();
        this.outstanding = istr.readInt();
        this.delivered = istr.readLong();
      }
    }]);

    return _class2;
  }(IceMX.Metrics);

  Slice.defineValue(IceMX.SubscriberMetrics, iceC_IceMX_SubscriberMetrics_ids[2], false);
  exports.IceMX = IceMX;
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
